#! /usr/bin/env lua
require "gtk"

-- test access to widget functions
win = gtk.window_new(gtk.WINDOW_TOPLEVEL)
win:set_title("Hello")


